aboutsummaryrefslogtreecommitdiffstats
path: root/tools/testing/selftests/rcutorture/bin/kvm.sh
diff options
context:
space:
mode:
Diffstat (limited to '')
-rwxr-xr-xtools/testing/selftests/rcutorture/bin/kvm.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/testing/selftests/rcutorture/bin/kvm.sh b/tools/testing/selftests/rcutorture/bin/kvm.sh
index 48b6a7248f50..ce05db324057 100755
--- a/tools/testing/selftests/rcutorture/bin/kvm.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm.sh
@@ -180,14 +180,14 @@ do
shift
;;
--torture)
- checkarg --torture "(suite name)" "$#" "$2" '^\(lock\|rcu\|rcuperf\|refperf\)$' '^--'
+ checkarg --torture "(suite name)" "$#" "$2" '^\(lock\|rcu\|rcuperf\|refscale\)$' '^--'
TORTURE_SUITE=$2
shift
- if test "$TORTURE_SUITE" = rcuperf || test "$TORTURE_SUITE" = refperf
+ if test "$TORTURE_SUITE" = rcuperf || test "$TORTURE_SUITE" = refscale
then
# If you really want jitter for refperf or
# rcuperf, specify it after specifying the rcuperf
# or the refperf. (But why jitter in these cases?)
jitter=0
fi
;;
@@ -180,14 +180,14 @@ do
then
- # If you really want jitter for refperf or
+ # If you really want jitter for refscale or
# rcuperf, specify it after specifying the rcuperf
@@ -180,14 +180,14 @@ do
# rcuperf, specify it after specifying the rcuperf
- # or the refperf. (But why jitter in these cases?)
+ # or the refscale. (But why jitter in these cases?)
jitter=0
fi